import type { Metadata, ResolvingMetadata } from 'next';

interface Props {
  params: { id: string };
}

function getMeme(id: string): string {
  const pinataImageUrl = `https://${process.env.PINATA_GATEWAY}/ipfs/${id}`
  return pinataImageUrl;
}

export async function generateMetadata(
  { params }: Props,
  parent: ResolvingMetadata
): Promise<Metadata> {
  const baseUrl = process.env.SITE_URL!;
  const meme = getMeme(params.id);

  return {
    title: '',
    description: '',
    metadataBase: new URL(baseUrl),
    openGraph: {
      type: 'website',
      url: `${baseUrl}/memes/${params.id}`,
      siteName: "Mark's meme market",
      images: [{ url: meme }],
    },
  };
}

export default function MemePage({ params }: Props) {
  const meme = getMeme(params.id);

  return (
    <main className="flex min-h-screen flex-col items-center justify-between p-24">
      <div className="relative flex flex-col items-center">
        <div className="relative w-full max-w-2xl aspect-square">
          <img
            src={meme}
            alt='Generated image'
            className="object-contain rounded-lg w-full h-full"
          />
        </div>
      </div>
    </main>
  );
}
