'use client'

import React from 'react'
import { WalletState, SUPPORTED_WALLETS } from '../services/walletService'

interface WalletHeaderProps {
  walletState: WalletState
  onConnect: (walletType: string) => Promise<void>
  onDisconnect: () => Promise<void>
}

const WalletHeader: React.FC<WalletHeaderProps> = ({ walletState, onConnect, onDisconnect }) => {
  return (
    <div className="w-full bg-slate-900/50 backdrop-blur-lg rounded-xl shadow-lg border border-orange-800/50 mb-8 p-4">
      {!walletState.connected ? (
        <div className="grid grid-cols-2 gap-4">
          {SUPPORTED_WALLETS.map((wallet) => (
            <button
              key={wallet.type}
              onClick={() => onConnect(wallet.type)}
              className="bg-gradient-to-r from-orange-500 to-amber-500 hover:from-orange-600 hover:to-amber-600
                       text-white font-semibold py-3 px-6 rounded-lg transition-all duration-200
                       shadow-lg hover:shadow-orange-500/25"
            >
              Connect {wallet.name}
            </button>
          ))}
        </div>
      ) : (
        <div className="flex flex-col sm:flex-row items-center justify-between">
          <span className="text-slate-300 mb-2 sm:mb-0">Connected Wallet</span>
          <span className="px-3 py-1 bg-amber-500/20 rounded-full text-amber-200 text-sm mb-2 sm:mb-0">
            {walletState.publicKey?.slice(0, 22)}...
          </span>
          <button
            onClick={onDisconnect}
            className="bg-red-500 hover:bg-red-600 text-white font-semibold py-2 px-4 rounded-lg transition-all duration-200 shadow-lg hover:shadow-red-500/25"
          >
            Disconnect
          </button>
        </div>
      )}
    </div>
  )
}

export default WalletHeader
