export interface GrokGenerationResult {
  imageUrl?: string
  error?: string
}

export async function generateWithGrok(prompt: string): Promise<GrokGenerationResult> {
  try {
    const response = await fetch('/api/grok', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({ prompt }),
    })

    if (!response.ok) {
      throw new Error('Failed to generate image')
    }

    const data = await response.json()
    console.log('Raw Grok response:', data)
    
    if (data.imageUrl) {
      return { imageUrl: data.imageUrl }
    } else {
      console.error('Unexpected response structure:', data)
      throw new Error('Invalid response format from Grok API')
    }
  } catch (error) {
    console.error('Grok generation error:', error)
    return { 
      error: error instanceof Error ? error.message : 'Generation failed'
    }
  }
}
